# WebU

Web Utils for browsing and scraping.

![](https://img.shields.io/pypi/v/webu?label=webu&color=blue&cacheSeconds=60)

## Install

```sh
pip install webu --upgrade
```

## Usage

Run example:

```sh
python example.py
```

See: [example.py](https://github.com/Hansimov/webu/blob/main/example.py)
